AdaptiveLayoutEngine class

Engine that determines the appropriate layout based on constraints and mode.

Constructors

AdaptiveLayoutEngine()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCrossAxisCount({required LayoutMode mode, required double width, required SliverGridDelegate? gridDelegate, double? minItemWidth}) int
Gets the effective cross-axis count for grid layout.
getEffectiveGridDelegate({required LayoutMode mode, required double width, required SliverGridDelegate? gridDelegate, double? minItemWidth, double defaultChildAspectRatio = 1.0, double defaultMainAxisSpacing = 0.0, double defaultCrossAxisSpacing = 0.0}) SliverGridDelegate?
Gets the effective SliverGridDelegate for the current layout.
shouldUseGrid({required LayoutMode mode, required double width, double? minItemWidth}) bool
Determines if the current layout should be a grid based on mode and width.