SelectionManager<T> class

Manages selection state for AdvancedListView items.

Inheritance

Constructors

SelectionManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isSelectionEnabled bool
Whether selection is currently enabled.
no setter
multiSelectEnabled bool
Whether multi-select mode is enabled.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItem → T?
Gets the currently selected item (for single-select).
no setter
selectedItems Set<T>
Gets all selected items (for multi-select).
no setter
selectionCount int
Gets the count of selected items.
no setter
singleSelectEnabled bool
Whether single-select mode is enabled.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearSelection() → void
Clears all selections.
deselectItem(T item) → void
Deselects an item.
disableSelection() → void
Disables all selection modes.
dispose() → void
Discards any resources used by the object.
inherited
enableMultiSelect() → void
Enables multi-select mode.
enableSingleSelect() → void
Enables single-select mode.
isSelected(T item) bool
Checks if an item is selected.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
selectAll(List<T> items) → void
Selects all items from a list.
selectItem(T item) → void
Selects an item.
toggleSelection(T item) → void
Toggles selection for an item.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited