IndexBar class

A vertical A-Z index bar for quick navigation.

Displays letters and allows tapping to jump to sections.

Inheritance

Constructors

IndexBar({Key? key, ValueChanged<String>? onIndexTap, required List<String> letters, double height = 400.0, double width = 30.0, TextStyle? textStyle, Color? highlightColor})
Creates an index bar.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
Height of the index bar.
final
highlightColor Color?
Color when a letter is highlighted.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letters List<String>
List of available index letters (e.g., A-Z).
final
onIndexTap ValueChanged<String>?
Callback when a letter is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
Text style for the letters.
final
width double
Width of each letter cell.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<IndexBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited