onLeadingSwipe property
Callback when item is swiped from left to right.
Implementation
final void Function(T item, int index)? onLeadingSwipe;
Callback when item is swiped from left to right.
final void Function(T item, int index)? onLeadingSwipe;