onTrailingSwipe property
Callback when item is swiped from right to left.
Implementation
final void Function(T item, int index)? onTrailingSwipe;
Callback when item is swiped from right to left.
final void Function(T item, int index)? onTrailingSwipe;