ResponsiveItemWrapper<T> class
Wraps an item with selection, swipe actions, and responsive constraints.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ResponsiveItemWrapper
Constructors
-
ResponsiveItemWrapper({Key? key, required T item, required int index, required Widget child, required BoxConstraints constraints, SelectionManager<
T> ? selectionManager, List<Widget> ? leadingActions, List<Widget> ? trailingActions, ValueChanged<T> ? onTap, ValueChanged<T> ? onLongPress, void onLeadingSwipe(T item, int index)?, void onTrailingSwipe(T item, int index)?, Duration? animationDuration}) -
Creates a responsive item wrapper.
const
Properties
- animationDuration → Duration?
-
Animation duration for item appearance.
final
- child → Widget
-
The child widget (the actual item content).
final
- constraints → BoxConstraints
-
Box constraints from the parent (for responsive sizing).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Index of the item.
final
- item → T
-
The item to display.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
leadingActions
→ List<
Widget> ? -
Leading swipe actions (left side on LTR).
final
- onLeadingSwipe → void Function(T item, int index)?
-
Callback when item is swiped from left to right.
final
-
onLongPress
→ ValueChanged<
T> ? -
Callback when item is long-pressed.
final
-
onTap
→ ValueChanged<
T> ? -
Callback when item is tapped.
final
- onTrailingSwipe → void Function(T item, int index)?
-
Callback when item is swiped from right to left.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectionManager
→ SelectionManager<
T> ? -
Selection manager for checking selection state.
final
-
trailingActions
→ List<
Widget> ? -
Trailing swipe actions (right side on LTR).
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited